==> huaweicloudsdkecs-3.0.84-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/associate_server_virtual_ip_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AssociateServerVirtualIpRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'nic_id': 'str',
        'body': 'AssociateServerVirtualIpRequestBody'
    }

    attribute_map = {
        'nic_id': 'nic_id',
        'body': 'body'
    }

    def __init__(self, nic_id=None, body=None):
        """AssociateServerVirtualIpRequest - a model defined in huaweicloud sdk"""
        
        

        self._nic_id = None
        self._body = None
        self.discriminator = None

        self.nic_id = nic_id
        if body is not None:
            self.body = body

    @property
    def nic_id(self):
        """Gets the nic_id of this AssociateServerVirtualIpRequest.

        云服务器网卡ID。

        :return: The nic_id of this AssociateServerVirtualIpRequest.
        :rtype: str
        """
        return self._nic_id

    @nic_id.setter
    def nic_id(self, nic_id):
        """Sets the nic_id of this AssociateServerVirtualIpRequest.

        云服务器网卡ID。

        :param nic_id: The nic_id of this AssociateServerVirtualIpRequest.
        :type: str
        """
        self._nic_id = nic_id

    @property
    def body(self):
        """Gets the body of this AssociateServerVirtualIpRequest.


        :return: The body of this AssociateServerVirtualIpRequest.
        :rtype: AssociateServerVirtualIpRequestBody
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AssociateServerVirtualIpRequest.


        :param body: The body of this AssociateServerVirtualIpRequest.
        :type: AssociateServerVirtualIpRequestBody
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssociateServerVirtualIpRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkecs-3.0.94-py2.py3-none-any.whl: huaweicloudsdkecs/v2/model/associate_server_virtual_ip_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AssociateServerVirtualIpRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'nic_id': 'str',
        'body': 'AssociateServerVirtualIpRequestBody'
    }

    attribute_map = {
        'nic_id': 'nic_id',
        'body': 'body'
    }

    def __init__(self, nic_id=None, body=None):
        """AssociateServerVirtualIpRequest

        The model defined in huaweicloud sdk

        :param nic_id: 云服务器网卡ID。
        :type nic_id: str
        :param body: Body of the AssociateServerVirtualIpRequest
        :type body: :class:`huaweicloudsdkecs.v2.AssociateServerVirtualIpRequestBody`
        """
        
        

        self._nic_id = None
        self._body = None
        self.discriminator = None

        self.nic_id = nic_id
        if body is not None:
            self.body = body

    @property
    def nic_id(self):
        """Gets the nic_id of this AssociateServerVirtualIpRequest.

        云服务器网卡ID。

        :return: The nic_id of this AssociateServerVirtualIpRequest.
        :rtype: str
        """
        return self._nic_id

    @nic_id.setter
    def nic_id(self, nic_id):
        """Sets the nic_id of this AssociateServerVirtualIpRequest.

        云服务器网卡ID。

        :param nic_id: The nic_id of this AssociateServerVirtualIpRequest.
        :type nic_id: str
        """
        self._nic_id = nic_id

    @property
    def body(self):
        """Gets the body of this AssociateServerVirtualIpRequest.


        :return: The body of this AssociateServerVirtualIpRequest.
        :rtype: :class:`huaweicloudsdkecs.v2.AssociateServerVirtualIpRequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this AssociateServerVirtualIpRequest.


        :param body: The body of this AssociateServerVirtualIpRequest.
        :type body: :class:`huaweicloudsdkecs.v2.AssociateServerVirtualIpRequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssociateServerVirtualIpRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
